"""{{ feature_name | capitalize }} models.

Define SQLAlchemy models for the {{ feature_name }} feature here.

Example:
    from sqlalchemy.orm import Mapped, mapped_column

    class {{ feature_name | capitalize }}(BaseModel):
        __tablename__ = "{{ feature_name }}s"

        name: Mapped[str] = mapped_column(unique=True)
        description: Mapped[str | None] = mapped_column(default=None)
"""

from db.database import BaseModel

__all__: list[str] = []

# Define your models below
# Example:
#
# class {{ feature_name | capitalize }}(BaseModel):
#     """{{ feature_name | capitalize }} model."""
#
#     __tablename__ = "{{ feature_name }}s"
#
#     name: Mapped[str] = mapped_column(unique=True)
#     description: Mapped[str | None] = mapped_column(default=None)
